@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## A real Try Catch Block Implementation Using Perl Filter - ~/lib/Nice/Try.pm
-## Version v1.0.4
+## Version v1.0.5
 ## Copyright(c) 2021 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2020/05/17
-## Modified 2021/05/31
+## Modified 2021/06/05
 ## All rights reserved
 ## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
@@ -17,18 +17,20 @@ BEGIN
     use strict;
     use warnings;
     use warnings::register;
+    # XXX Only for debugging
+    # use Devel::Confess;
     use IO::File;
     use PPI;
     use Filter::Util::Call;
     use Scalar::Util ();
     use List::Util ();
     use Want ();
-    our $VERSION = 'v1.0.4';
+    our $VERSION = 'v1.0.5';
     our $ERROR;
     our( $CATCH, $DIED, $EXCEPTION, $FINALLY, $HAS_CATCH, @RETVAL, $SENTINEL, $TRY, $WANTARRAY );
 }
 
-## Taken from Try::Harder version 0.005
+# Taken from Try::Harder version 0.005
 our $SENTINEL = bless( {} => __PACKAGE__ . '::SENTINEL' );
 
 sub import
@@ -107,7 +109,10 @@ sub filter
     return( $line ) if( !$line );
     unless( $status < 0 )
     {
-        ## $self->_message( 5, "Processing at line $line code:\n$code" );
+        # $self->_message( 5, "Processing at line $line code:\n$code" );
+        # 2021-06-05 (Jacques): fixes the issue No. 3 <https://git.deguest.jp/jack/Nice-Try/issues/3>
+        # Make sure there is at least a space at the beginning
+        $code = ' ' . $code;
         my $doc = PPI::Document->new( \$code, readonly => 1 ) || die( "Unable to parse: ", PPI::Document->errstr, "\n$code\n" );
         if( $doc = $self->_parse( $doc ) )
         {
@@ -115,7 +120,7 @@ sub filter
             # $doc->save( "./dev/debug-parsed.pl" );
             # $status = 1;
         }
-        ## Rollback
+        # Rollback
         else
         {
             # $self->_message( 5, "Nothing found, restoring code to '$code'" );
@@ -224,6 +229,7 @@ sub _parse
     {
         return( $self->_error( "Element provided to parse is not a PPI::Node object" ) );
     }
+    
     my $ref = $elem->find(sub
     {
         my( $top, $this ) = @_;
@@ -233,9 +239,9 @@ sub _parse
     $self->_messagef( 4, "Found %d match(es)", scalar( @$ref ) );
     return if( !scalar( @$ref ) );
     
-    ## 2020-09-13: PPI will return 2 or more consecutive try-catch block as 1 statement
-    ## It does not tell them apart, so we need to post process the result to effectively search within for possible for other try-catch blocks and update the @$ref array consequently
-    ## Array to contain the new version of the $ref array.
+    # 2020-09-13: PPI will return 2 or more consecutive try-catch block as 1 statement
+    # It does not tell them apart, so we need to post process the result to effectively search within for possible for other try-catch blocks and update the @$ref array consequently
+    # Array to contain the new version of the $ref array.
     my $alt_ref = [];
     $self->_message( 3, "Checking for consecutive try-catch blocks in results found by PPI" );
     foreach my $this ( @$ref )
@@ -250,15 +256,15 @@ sub _parse
         my $sib;
         while( $sib = $prev_sib->next_sibling )
         {
-            ## We found a try-catch block. Move the buffer to $alt_ref
+            # We found a try-catch block. Move the buffer to $alt_ref
             if( $sib->class eq 'PPI::Token::Word' && $sib->content eq 'try' )
             {
-                ## Look ahead for a block...
+                # Look ahead for a block...
                 my $next = $sib->snext_sibling;
                 if( $next && $next->class eq 'PPI::Structure::Block' )
                 {
                     $self->_message( 3, "Found consecutive try-block." );
-                    ## Push the previous statement $st to the stack $alt_ref
+                    # Push the previous statement $st to the stack $alt_ref
                     $self->_messagef( 3, "Saving previous %d nodes collected.", scalar( @$tmp_nodes ) );
                     push( @$tmp_ref, $tmp_nodes );
                     $tmp_nodes = [];
@@ -270,7 +276,7 @@ sub _parse
         $self->_messagef( 3, "Saving last %d nodes collected.", scalar( @$tmp_nodes ) );
         push( @$tmp_ref, $tmp_nodes );
         $self->_messagef( 3, "Found %d try-catch block(s) in initial PPI result.", scalar( @$tmp_ref ) );
-        ## If we did find consecutive try-catch blocks, we add each of them after the nominal one and remove the nominal one after. The nominal one should be empty by then
+        # If we did find consecutive try-catch blocks, we add each of them after the nominal one and remove the nominal one after. The nominal one should be empty by then
         if( scalar( @$tmp_ref ) > 1 )
         {
             my $last_obj = $this;
@@ -278,28 +284,66 @@ sub _parse
             foreach my $arr ( @$tmp_ref )
             {
                 $self->_message( 3, "Adding statement block with ", scalar( @$arr ), " children after '$last_obj'" );
-                ## Get the trailing insignificant elements at the end of the statement and move them out of the statement
+                # 2021-06-05 (Jacques): Fixing issue No. 2: <https://git.deguest.jp/jack/Nice-Try/issues/2>
+                # Find the last block that belongs to us
+                $self->_message( 4, "Checking first level objects collected." );
+                my $last_control = '';
+                my $last_block;
+                my $last = {};
+                foreach my $o ( @$arr )
+                {
+                    # $self->_message( 4, "Found object '$o' of class '", $o->class, "' (", overload::StrVal( $o ), ")." );
+                    if( $o->class eq 'PPI::Structure::Block' && $last_control )
+                    {
+                        $last->{block} = $o;
+                        $last->{control} = $last_control;
+                        $last_control = '';
+                    }
+                    elsif( $o->class eq 'PPI::Token::Word' )
+                    {
+                        my $ct = $o->content;
+                        if( $ct eq 'try' || $ct eq 'catch' || $ct eq 'finally' )
+                        {
+                            $last_control = $o;
+                        }
+                    }
+                }
+                # $self->_message( 4, "Last control was '$last->{control}' and last block '$last->{block}' (", overload::StrVal( $last->{block} ), ")." );
+                
+                # Get the trailing insignificant elements at the end of the statement and move them out of the statement
                 my $insignificants = [];
                 while( scalar( @$arr ) > 0 )
                 {
                     my $o = $arr->[-1];
-                    ## $self->_message( 3, "Checking trailing object with class '", $o->class, "' and value '$o'" );
-                    last if( $o->class eq 'PPI::Structure::Block' );
+                    # $self->_message( 4, "Checking trailing object with class '", $o->class, "' and value '$o'" );
+                    # 2021-06-05 (Jacques): We don't just look for the last block, because
+                    # that was making a bad assumption that the last trailing block would be our
+                    # try-catch block.
+                    # Following issue No. 2 reported with a trailing anonymous subroutine,
+                    # We remove everything up until our known last block that belongs to us.
+                    last if( $o->class eq 'PPI::Structure::Block' && Scalar::Util::refaddr( $o ) eq Scalar::Util::refaddr( $last->{block} ) );
                     unshift( @$insignificants, pop( @$arr )->remove );
                 }
-                ## $self->_messagef( 3, "%d insignificant objects found.", scalar( @$insignificants ) );
+                $self->_messagef( 3, "%d insignificant objects found.", scalar( @$insignificants ) );
                 
-                my $st = PPI::Statement->new;
-                ## $self->_messagef( 3, "Adding the updated statement objects with %d children.", scalar( @$arr ) );
+                my $new_code = join( '', map( "$_", @$arr ) );
+                # $self->_message( 4, "New code is: '$new_code'" );
+                # 2021-06-05 (Jacques): It is unfortunately difficult to simply add a new PPI::Statement object
+                # Instead, we have PPI parse our new code and we grab what we need.
+                my $new_block = PPI::Document->new( \$new_code, readonly => 1 );
+                # $self->_message( 4, "New block code is: '$new_block'" );
+                # $self->_browse( $new_block );
+                my $st = $new_block->{children}->[0]->remove;
+                # $self->_message( 4, "Statemnt now contains: '$st'" );
+                
+                # $self->_messagef( 3, "Adding the updated statement objects with %d children.", scalar( @$arr ) );
                 foreach my $o ( @$arr )
                 {
-                    ## We remove the object from its parent, because, as per the documentation, an object can only have one parent
-                    ## Without removing, this would simply fail. The object added would be empty.
+                    # We remove the object from its parent, now that it has become useless
                     my $old = $o->remove || die( "Unable to remove element '$o'\n" );
-                    $st->add_element( $old );
                 }
                 my $err = '';
-                $self->_messagef( 3, "Adding the statement object after last object '%s' of class '%s' with parent with class '%s'.", Scalar::Util::refaddr( $last_obj ), $last_obj->class, $last_obj->parent->class );
+                $self->_messagef( 3, "Adding the statement object after last object '%s' of class '%s' with parent with class '%s'.", Scalar::Util::refaddr( $last_obj ), ( defined( $last_obj ) ? $last_obj->class : 'undefined class' ), ( defined( $last_obj ) ? $last_obj->parent->class : 'undefined parent class' ) );
                 $self->_message( 4, "In other word, adding:\n'$st'\nAFTER:\n'$last_obj'" );
                 # my $rc = $last_obj->insert_after( $st );
                 my $rc;
@@ -325,10 +369,10 @@ sub _parse
                     $last_obj = $st;
                     if( scalar( @$insignificants ) )
                     {
-                        ## $self->_messagef( 3, "Adding %d trailing insignificant objects after last element of class '%s'", scalar( @$insignificants ), $last_obj->class );
+                        $self->_messagef( 4, "Adding %d trailing insignificant objects after last element of class '%s'", scalar( @$insignificants ), $last_obj->class );
                         foreach my $o ( @$insignificants )
                         {
-                            ## $self->_messagef( 3, "Adding trailing insignificant object of class '%s' after last element of class '%s'", $o->class, $last_obj->class );
+                            $self->_messagef( 4, "Adding trailing insignificant object of class '%s' after last element of class '%s'", $o->class, $last_obj->class );
                             ## printf( STDERR "Inserting object '%s' (%s) of type '%s' after object '%s' (%s) of type %s who has parent '%s' of type '%s'\n", overload::StrVal( $o ), Scalar::Util::refaddr( $o ), ref( $o ), overload::StrVal( $last_obj), Scalar::Util::refaddr( $last_obj ), ref( $last_obj ), overload::StrVal( $last_obj->parent ), ref( $last_obj->parent ) );
                             eval
                             {
@@ -383,7 +427,9 @@ sub _parse
     foreach my $this ( @$ref )
     {
         $self->_browse( $this ) if( $self->{debug} >= 5 );
+        # $self->_message( 4, "\$this is of class '", $this->class, "' and its parent of class '", $this->parent->class, "'." );
         my $element_before_try = $this->previous_sibling;
+        # $self->_message( 4, "Is \$element_before_try defined ? ", defined( $element_before_try ) ? 'Yes' : 'No', "(", overload::StrVal( $element_before_try ), ") -> '$element_before_try'" );
         my $try_block_ref = [];
         ## Contains the finally block reference
         my $fin_block_ref = [];
@@ -539,16 +585,16 @@ sub _parse
                     push( @$nodes_to_replace, $sib );
                 }
             }
-            ## Check for new lines after closing blocks. The ones before, we can account for them in each section above
-            ## We could have } catch {
-            ## or
-            ## }
-            ## catch {
-            ## etc.
-            ## This could also be new lines following the last catch block
+            # Check for new lines after closing blocks. The ones before, we can account for them in each section above
+            # We could have } catch {
+            # or
+            # }
+            # catch {
+            # etc.
+            # This could also be new lines following the last catch block
             elsif( $sib->class eq 'PPI::Token::Whitespace' && $sib->content =~ /[\015\012]+/ )
             {
-                ## $self->_messagef( 4, "Between -> Found closing new line at line %d", $sib->line_number );
+                # $self->_messagef( 4, "Between -> Found closing new line at line %d", $sib->line_number );
                 $nl_counter++;
                 push( @$buff, $sib );
             }
@@ -593,22 +639,22 @@ EOT
             }
         }
 
-        ## Found any try block at all?
+        # Found any try block at all?
         if( scalar( @$try_block_ref ) )
         {
-            ## $self->_message( 3, "Original code to remove is:\n", join( '', @$nodes_to_replace ) );
-            ## $self->_message( 3, "Try definition: ", $try_block_ref->[0]->{block}->content );
-            ## $self->_messagef( 3, "%d catch clauses found", scalar( @$catch_def ) );
+            # $self->_message( 3, "Original code to remove is:\n", join( '', @$nodes_to_replace ) );
+            # $self->_message( 3, "Try definition: ", $try_block_ref->[0]->{block}->content );
+            # $self->_messagef( 3, "%d catch clauses found", scalar( @$catch_def ) );
             foreach my $c ( @$catch_def )
             {
-                ## $self->_message( 3, "Catch variable assignment: ", $c->{var} );
-                ## $self->_message( 3, "Catch block: ", $c->{block} );
+                # $self->_message( 3, "Catch variable assignment: ", $c->{var} );
+                # $self->_message( 3, "Catch block: ", $c->{block} );
             }
             my $try_def = $try_block_ref->[0];
-            ## $self->_messagef( 3, "Try new lines before block: %d, after block %d", $try_def->{open_curly_nl}, $try_def->{close_curly_nl} );
+            # $self->_messagef( 3, "Try new lines before block: %d, after block %d", $try_def->{open_curly_nl}, $try_def->{close_curly_nl} );
             
-            ## Checking for embedded try-catch
-            ## $self->_message( 4, "Checking for embedded try-catch in ", $try_def->{block} );
+            # Checking for embedded try-catch
+            # $self->_message( 4, "Checking for embedded try-catch in ", $try_def->{block} );
             if( my $emb = $self->_parse( $try_def->{block} ) )
             {
                 $try_def->{block} = $emb;
@@ -762,12 +808,12 @@ EOT
                 $try_sub =~ s/__TRY__CLOSE_NL__//gs;
             }
             
-            ## Add the final block if there is no catch block, otherwise the final block comes at the end below
+            # Add the final block if there is no catch block, otherwise the final block comes at the end below
             if( !$has_catch_clause )
             {
                 $try_sub =~ s/__FINALLY_BLOCK__/$fin_block/gs;
             }
-            ## If it should not be here, remove the placeholder
+            # If it should not be here, remove the placeholder
             else
             {
                 $try_sub =~ s/__FINALLY_BLOCK__//gs;
@@ -776,7 +822,7 @@ EOT
         }
         else
         {
-            ## $self->_message( 3, "** No try block found!!" );
+            # $self->_message( 3, "** No try block found!!" );
             next;
         }
         
@@ -790,15 +836,15 @@ EOT
         push( @$catch_repl, $if_start );
         if( scalar( @$catch_def ) )
         {
-            ## $self->_messagef( 3, "Found %d catch blocks", scalar( @$catch_def ) );
+            # $self->_messagef( 3, "Found %d catch blocks", scalar( @$catch_def ) );
             my $total_catch = scalar( @$catch_def );
-            ## To count how many times we have else's – obviously we should not have more than 1
+            # To count how many times we have else's – obviously we should not have more than 1
             my $else = 0;
             for( my $i = 0; $i < $total_catch; $i++ )
             {
                 my $cdef = $catch_def->[$i];
-                ## $self->_messagef( 3, "Catch No ${i} new lines before block: %d, after block %d", $cdef->{open_curly_nl}, $cdef->{close_curly_nl} );
-                ## Checking for embedded try-catch
+                # $self->_messagef( 3, "Catch No ${i} new lines before block: %d, after block %d", $cdef->{open_curly_nl}, $cdef->{close_curly_nl} );
+                # Checking for embedded try-catch
                 if( my $emb = $self->_parse( $cdef->{block} ) )
                 {
                     $cdef->{block} = $emb;
@@ -806,8 +852,8 @@ EOT
                 
                 if( $cdef->{var} )
                 {
-                    ## $self->_messagef( 3, "Catch assignment is: '%s'", $cdef->{var}->content );
-                    ## my $str = $cdef->{var}->content;
+                    # $self->_messagef( 3, "Catch assignment is: '%s'", $cdef->{var}->content );
+                    # my $str = $cdef->{var}->content;
                     my $str = $self->_serialize( $cdef->{var} );
                     $str =~ s/^\([[:blank:]]*|[[:blank:]]*\)$//g;
                     if( $str =~ /^(\S+)[[:blank:]]+(\$\S+)$/ )
@@ -823,15 +869,15 @@ EOT
                 }
                 else
                 {
-                    ## $self->_message( 3, "No Catch assignment found" );
+                    # $self->_message( 3, "No Catch assignment found" );
                 }
                 if( $cdef->{block} )
                 {
-                    ## $self->_messagef( 3, "Catch block is:\n%s", $cdef->{block}->content );
+                    # $self->_messagef( 3, "Catch block is:\n%s", $cdef->{block}->content );
                 }
                 else
                 {
-                    ## $self->_message( 3, "No catch block found!" );
+                    # $self->_message( 3, "No catch block found!" );
                     next;
                 }
                 my $cond;
@@ -851,8 +897,8 @@ EOT
                 {
                     $cond = 'elsif';
                 }
-                ## $self->_message( 3, "\$i = $i, \$total_catch = $total_catch and cond = '$cond'" );
-                ## my $block = $cdef->{block}->content;
+                # $self->_message( 3, "\$i = $i, \$total_catch = $total_catch and cond = '$cond'" );
+                # my $block = $cdef->{block}->content;
                 $self->_process_loop_breaks( $cdef->{block} );
                 $self->_process_caller( catch => $cdef->{block} );
                 my $block = $self->_serialize( $cdef->{block} );
@@ -941,15 +987,15 @@ $catch_code
         }
 EOT
                     }
-                    ## No class, just variable assignment like $e or something
+                    # No class, just variable assignment like $e or something
                     else
                     {
-                        ## $self->_message( 3, "Called here for fallback for element No $i" );
+                        # $self->_message( 3, "Called here for fallback for element No $i" );
                         if( ++$else > 1 )
                         {
-                            ## CORE::warn( "Cannot have more than one falllback catch clause for block: ", $cdef->{block}->content, "\n" ) if( warnings::enabled );
+                            # CORE::warn( "Cannot have more than one falllback catch clause for block: ", $cdef->{block}->content, "\n" ) if( warnings::enabled );
                             CORE::warn( "Cannot have more than one falllback catch clause for block: ", $self->_serialize( $cdef->{block} ), "\n" ) if( warnings::enabled );
-                            ## Skip, not die. Not fatal, just ignored
+                            # Skip, not die. Not fatal, just ignored
                             next;
                         }
                         $cond = "${cond}( 1 )" if( $cond eq 'if' || $cond eq 'elsif' );
@@ -964,7 +1010,7 @@ $catch_code
 EOT
                     }
                 }
-                ## No variable assignment like $e
+                # No variable assignment like $e
                 else
                 {
                     $cond = "${cond}( 1 )" if( $cond eq 'if' || $cond eq 'elsif' );
@@ -996,7 +1042,7 @@ EOT
                 }
                 push( @$catch_repl, $catch_section );
             }
-            ## End catch loop
+            # End catch loop
             # Tilmann Haeberle (TH) 2021-03-25: Fix: put an else at the end to avoid 'fall_through' issue unless an else exists already
             my $if_end;
             if( $else )
@@ -1018,11 +1064,11 @@ EOT
             $if_end =~ s/\n/ /g unless( $self->{debug_code} );
             push( @$catch_repl, $if_end );
         }
-        ## No catch clause
+        # No catch clause
         else
         {
-            ## If the try-catch block is called inside an eval, propagate the exception
-            ## Otherwise, we just make the $@ available
+            # If the try-catch block is called inside an eval, propagate the exception
+            # Otherwise, we just make the $@ available
             my $catch_else = <<EOT;
     }
     else
@@ -1041,13 +1087,13 @@ EOT
             push( @$catch_repl, $catch_else );
         }
         
-        ## Add
+        # Add
         my $catch_res = scalar( @$catch_repl ) ? join( '', @$catch_repl ) : '';
         push( @$repl, $catch_res ) if( $catch_res );
-        ## Closing the If DIED condition
+        # Closing the If DIED condition
         push( @$repl, "\};" );
 
-        ## If there is a catch clause, we put the final block here, if any
+        # If there is a catch clause, we put the final block here, if any
         if( $has_catch_clause && CORE::length( $fin_block ) )
         {
             push( @$repl, $fin_block );
@@ -1060,15 +1106,15 @@ if( CORE::defined( \$Nice::Try::WANTARRAY ) and
       ( Scalar::Util::blessed( \$Nice::Try::RETVAL[0] ) && !\$Nice::Try::RETVAL[0]->isa( 'Nice::Try::SENTINEL' ) ) 
     ) ) 
 {
-    if( \$Nice::Try::RETVAL[0] eq '__NEXT__' )
+    if( CORE::defined( \$Nice::Try::RETVAL[0] ) && \$Nice::Try::RETVAL[0] eq '__NEXT__' )
     {
         \$Nice::Try::BREAK = 'next';
     }
-    elsif( \$Nice::Try::RETVAL[0] eq '__LAST__' )
+    elsif( CORE::defined( \$Nice::Try::RETVAL[0] ) && \$Nice::Try::RETVAL[0] eq '__LAST__' )
     {
         \$Nice::Try::BREAK = 'last';
     }
-    elsif( \$Nice::Try::RETVAL[0] eq '__REDO__' )
+    elsif( CORE::defined( \$Nice::Try::RETVAL[0] ) && \$Nice::Try::RETVAL[0] eq '__REDO__' )
     {
         \$Nice::Try::BREAK = 'redo';
     }
@@ -1080,15 +1126,15 @@ if( CORE::defined( \$Nice::Try::WANTARRAY ) and
         }
         elsif( \$Nice::Try::WANT eq 'VOID' )
         {
-            if( \$Nice::Try::RETVAL[0] eq '__NEXT__' )
+            if( CORE::defined( \$Nice::Try::RETVAL[0] ) && \$Nice::Try::RETVAL[0] eq '__NEXT__' )
             {
                 \$Nice::Try::BREAK = 'next';
             }
-            elsif( \$Nice::Try::RETVAL[0] eq '__LAST__' )
+            elsif( CORE::defined( \$Nice::Try::RETVAL[0] ) && \$Nice::Try::RETVAL[0] eq '__LAST__' )
             {
                 \$Nice::Try::BREAK = 'last';
             }
-            elsif( \$Nice::Try::RETVAL[0] eq '__REDO__' )
+            elsif( CORE::defined( \$Nice::Try::RETVAL[0] ) && \$Nice::Try::RETVAL[0] eq '__REDO__' )
             {
                 \$Nice::Try::BREAK = 'redo';
             }
@@ -1133,15 +1179,15 @@ if( CORE::defined( \$Nice::Try::WANTARRAY ) and
 }
 elsif( scalar( \@Nice::Try::VOID ) )
 {
-    if( \$Nice::Try::VOID[0] eq '__NEXT__' )
+    if( CORE::defined( \$Nice::Try::VOID[0] ) && \$Nice::Try::VOID[0] eq '__NEXT__' )
     {
         \$Nice::Try::BREAK = 'next';
     }
-    elsif( \$Nice::Try::VOID[0] eq '__LAST__' )
+    elsif( CORE::defined( \$Nice::Try::VOID[0] ) && \$Nice::Try::VOID[0] eq '__LAST__' )
     {
         \$Nice::Try::BREAK = 'last';
     }
-    elsif( \$Nice::Try::VOID[0] eq '__REDO__' )
+    elsif( CORE::defined( \$Nice::Try::VOID[0] ) && \$Nice::Try::VOID[0] eq '__REDO__' )
     {
         \$Nice::Try::BREAK = 'redo';
     }
@@ -1177,19 +1223,20 @@ EOT
         $envelop =~ s/__TRY_CATCH_CODE__/$try_catch_code/;
         my $token = PPI::Token->new( $envelop ) || die( "Unable to create token" );
         $token->set_class( 'Structure' );
-        ## $self->_messagef( 3, "Token is '$token' and of class '%s' and inherit from PPI::Token? %s", $token->class, ($token->isa( 'PPI::Token' ) ? 'yes' : 'no' ) );
+        # $self->_messagef( 3, "Token is '$token' and of class '%s' and inherit from PPI::Token? %s", $token->class, ($token->isa( 'PPI::Token' ) ? 'yes' : 'no' ) );
         my $struct = PPI::Structure->new( $token ) || die( "Unable to create PPI::Structure element" );
-        ## $self->_message( 3, "Resulting try-catch block is:\n'$token'" );
+        # $self->_message( 3, "Resulting try-catch block is:\n'$token'" );
         my $orig_try_catch_block = join( '', @$nodes_to_replace );
-        ## $self->_message( 3, "Original try-catch block is:\n'$orig_try_catch_block'" );
-        ## $self->_messagef( 3, "Element before our try-catch block is of class %s with value '%s'", $element_before_try->class, $element_before_try->content );
-        if( !( my $rc = $element_before_try->insert_after( $token ) ) )
+        # $self->_message( 3, "Original try-catch block is:\n'$orig_try_catch_block'" );
+        # $self->_messagef( 3, "Element before our try-catch block is of class %s with value '%s'", $element_before_try->class, $element_before_try->content );
+        my $rc;
+        if( !( $rc = $element_before_try->insert_after( $token ) ) )
         {
-            ## $self->_message( 3, "Return code is defined? ", CORE::defined( $rc ) ? 'yes' : 'no', " and is it a PPI::Element object? ", $token->isa( 'PPI::Element' ) ? 'yes' : 'no' );
+            # $self->_message( 3, "Return code is defined? ", CORE::defined( $rc ) ? 'yes' : 'no', " and is it a PPI::Element object? ", $token->isa( 'PPI::Element' ) ? 'yes' : 'no' );
             $self->_error( "Failed to add replacement code of class '", $token->class, "' after '$element_before_try'" );
             next;
         }
-        ## $self->_message( 3, "Return code is defined? ", defined( $rc ) ? "yes" : "no" );
+        $self->_message( 3, "Return code is defined? ", defined( $rc ) ? "yes" : "no" );
         
         for( my $k = 0; $k < scalar( @$nodes_to_replace ); $k++ )
         {
@@ -1198,9 +1245,9 @@ EOT
             $e->delete || warn( "Could not remove node No $k: '$e'\n" );
         }
     }
-    ## End foreach catch found
+    # End foreach catch found
     
-    ## $self->_message( 3, "\n\nResulting code is\n", $elem->content );
+    # $self->_message( 3, "\n\nResulting code is\n", $elem->content );
     return( $elem );
 }
 
@@ -1650,7 +1697,7 @@ Also since version 1.0.0, L<Nice::Try> is context aware:
 
 =head1 VERSION
 
-    v1.0.4
+    v1.0.5
 
 =head1 DESCRIPTION
 
